MySQL-AutoXtrabackup
====================

MySQL AutoXtrabackup commandline tool written in Python 3.
For community from Azerbaijan MySQL User Community: [MySQL Azerbaijan Community](http://mysql.az/).
For any question please ask: [Email](mailto:rzayev.shahriyar@yandex.com)

Read full documentation here:
-----------------------------

[**MySQL-AutoXtrabackup documentation!**](http://mysql-autoxtrabackup.readthedocs.io/en/latest/index.html)



		